Description Usage Arguments Details Value
The CompCor algorithm (Behzadi et. al., 2007) 10.1016/j.neuroimage.2007.04.042
1 2 3 4 5 6 7 8 |
vol |
The I x J x K x T volumetric fMRI timeseries, including both
the data voxels (unless |
data_ROI |
A logical mask for |
data |
A V x T data matrix from which the noise components
will be regressed. Up to one of |
noise_ROI |
A list of logical masks for |
noise_nPC |
A vector the same length as |
noise_erosion |
The number of layers to erode from each of the
|
The data are centered on each voxel timecourse's median.
A list with entries "data", "noise", "noise_mask"
and "noise_var".
If data_ROI or data was provided, the entry "data" will be a
V x T matrix where each row is a data voxel (if data_ROI was
provided, the voxels are in spatial order; if data was provided, the
voxels are in the same order) time series with each noise PC regressed from
it. Otherwise, this entry will be NULL.
The entry "noise" is a list of T x noise_nPC PC
scores, one for each noise_ROI.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.